Learn R Programming

units (version 0.4-6)

deparse_unit: deparse unit to string in product power form (e.g. km m-2 s-1)

Description

deparse unit to string in product power form (e.g. km m-2 s-1)

Usage

deparse_unit(x)

as_cf(x)

Arguments

x

object of class units

Value

length one character vector

Details

as_cf is deprecated; use deparse_unit.

Examples

Run this code
# NOT RUN {
u = parse_unit("kg m-2 s-1")
u
deparse_unit(u)
# }

Run the code above in your browser using DataLab