Learn R Programming

units (version 0.4-6)

units: Set measurement units on a numeric vector

Description

Set measurement units on a numeric vector

Convert units

retrieve measurement units from units object

Usage

# S3 method for numeric
units(x) <- value

# S3 method for units units(x) <- value

set_units(x, value, ...)

# S3 method for units set_units(x, value, ...)

# S3 method for numeric set_units(x, value = units::unitless, ...)

# S3 method for units units(x)

Arguments

x

numeric vector, or object of class units

value

object of class units or symbolic_units, or in the case of set_units expression with symbols that can be resolved in ud_units (see examples).

...

ignored

Value

object of class units

the units method retrieves the units attribute, which is of class symbolic_units

Details

set_units is a pipe-friendly version of units<- that evaluates value first in the environment of ud_units.

Examples

Run this code
# NOT RUN {
x = 1:3
class(x)
units(x) <- with(ud_units, m/s) # valid
class(x)
y = 2:5
a <- with(ud_units, 1:3 * m/s)
units(a) <- with(ud_units, km/h)
a
# note that these units have NOT been defined or declared before:
set_units(1:5, N/m^2)
set_units(1:5, unitless) # unit "1", unitless
if (require(magrittr)) {
 1:5 %>% set_units(N/m^2)
 1:10 %>% set_units(m) %>% set_units(km)
}
# }

Run the code above in your browser using DataLab